/********************************************************
 * MAT 259 - Winter 2018                                *
 * Final Project: TED Talk                              *    
 *                                                      *
 * By: Annika Tan                                       *
 * Supervisor: Rodger Luo                               *
 *                                                      *
 * Objective: The goal of my text mining project is to  *
 * build a visual classifier that breaks each text      *
 * into designated clusters.                            *
 *                                                      *
 *                                                      *
 ********************************************************/


/* 
  Force directed graph
 */

import toxi.geom.*;
import toxi.physics2d.*;
import toxi.physics2d.behaviors.*;

// Data
Table table;

// Reference to physics world
VerletPhysics2D physics;

// A list of cluster objects
ArrayList clusters;

// Boolean that indicates whether we draw connections or not
boolean showPhysics = true;
boolean showParticles = true;

// Font
PFont f;

// Peasy
import peasy.*;
PeasyCam cam;

color colour[] = {#EDA3D8, #EA86A6, #BB99CB, #89BAE7, #41CCB9, #C9B2EB};
/*, #EAB451, #CAA246, #F18F61,
#63C6E2, #4DD9B8, #9BDF7D, #F3D65C, #F09B58, #EB8960, #EA85A4, #BEA6DB, #94C4F4}; //17
*/

void setup() {
  //size(800,800,P3D);
  fullScreen(P3D);
  surface.setResizable(true);
  //ellipse(width/2, height/2, height, height);
  
  smooth();
  frameRate(80);
  f = createFont("Georgia",12,true);
  table = loadTable("tags50.csv", "header");
  
  /// keep cp5 on the top of 3D without rotation when camera angle changes
  hint(DISABLE_DEPTH_TEST);
  //cam.beginHUD();
  //cp5.draw();
  drawInfo();
  //cam.endHUD();
  hint(ENABLE_DEPTH_TEST);

  // Initialize the physics
  physics=new VerletPhysics2D();
  physics.setWorldBounds(new Rect(10,10,width-20,height-20));
  cam = new PeasyCam(this, 0,0,0, 5000);
  cam.setWheelScale(0.2);
  //cam.setMinimumDistance(-2000);
  //cam.setMaximumDistance(3000);


  // Spawn a new random graph
  newGraph(table);

}

void draw() {

  // Update the physics world
  physics.update();

  background(255);
  //translate(width/2, height/2, 0);
  translate(0, 0, 100);
  // Display all points
  if (showParticles) {
    int[] a =  {1,2,3,4,5,6,7};
    int[] b = {1,2,3,4,5,6,7};
    for (int i = 0; i < clusters.size(); i++) {
      Cluster c = (Cluster) clusters.get(i);
      c.display();
      beginShape(LINES);
      stroke(colour[a[i]-1]);
      stroke(colour[b[i]-1]);
      endShape();
      
    }
  }

  // atan: draws lines
  // If we want to see the physics
  
  if (showPhysics) {
    int[] a =  {1,2,3,4,5,6,7};
    int[] b = {1,2,3,4,5,6,7};
    for (int i = 0; i < clusters.size(); i++) {
      // Cluster internal connections
      Cluster ci = (Cluster) clusters.get(i);
      ci.showConnections();
     
      beginShape(LINES);
      stroke(colour[a[i]-1]);
      stroke(colour[b[i]-1]);
      endShape();
      

      // Cluster connections to other clusters
      for (int j = i+1; j < clusters.size(); j++) {
        Cluster cj = (Cluster) clusters.get(j);
        // comment out
        // ci.showConnections(cj);
      }
    }
  }
  
  rotateY(mouseX*1.0f/width*TWO_PI);
  rotateX(mouseY*1.0f/height*TWO_PI);
  
  // Instructions
  fill(0);
  textFont(f);
  
  //drawInfo();
  //text("'p' to display or hide particles\n'c' to display or hide connections\n'n' for new graph",10,20);
}